@@ -4,38 +4,13 @@ package Log::ProgramInfo;
 
 Log::ProgramInfo - log global info from a perl programs.
 
-=cut
-
-### HISTORY ###################################################################
-# Version               Date            Developer        Comments
-# 0.1.1                 2015-04-02      John Macdonald   Initial release to CPAN
-# 0.1.2                 2015-04-04      John Macdonald   Minor cleanups to initial release
-# 0.1.3                 2015-04-09      John Macdonald   Rename s/JobInof/ProgramInfo/
-# 0.1.4                 2015-04-09      John Macdonald   Add README
-# 0.1.5                 2015-04-10      John Macdonald   Change log extension and env
-#                                                        variable names to reflect
-#                                                        the ProgramInfo name.
-# 0.1.6                 2015-04-23      John Macdonald   Fix env name ..._FILE -> ..._NAME
-#                                                        Fix env handling - capture at start
-#                                                                         - apply at end
-#                                                        Log username(s) groupname(s)
-#                                                        Include identifying info in separator line
-#                                                        Make output more easily parsable
-# 0.1.7                 2015-05-20      John Macdonald   Add user-pluggable log routines
-#                                                        Move log parser from test to module.
-# 0.1.8                 2015-06-12      John Macdonald   Catch most signals (not just HUP)
-# 0.1.9                 2016-02-23      John Macdonald   Additions to match paper requests
-# 0.1.10                2016-02-25      John Macdonald   Typo in 0.1.9
-# 0.1.11                2016-02-25      John Macdonald   Changes file was not included in MANIFEST
-#
-
 =head1 VERSION
 
-Version 0.1.11
+Version 0.1.12
 
 =cut
 
-our $VERSION = '0.1.11';
+our $VERSION = '0.1.12';
 
 use feature qw(say);
 use Data::Dumper;
@@ -404,6 +379,7 @@ my $log;
 
 sub log_entry {
     my $msg;
+    @_ = map { $_ // 'NO_VALUE_FOUND' } @_;
     if (@_ == 2 ) {
         $msg = sprintf "%-7s : %s", @_;
     } elsif (@_ == 3 ) {
